==> galette-0.9.3.1.tar.bz2: galette-0.9.3.1/galette/config/versions.inc.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * External libraries versions
 * Defines various library versions, to avoid use of problematic symlinks under windows or via FTP.
 *
 * PHP version 5
 *
 * Copyright © 2009-2014 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Config
 * @package   Galette
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2009-2014 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version   SVN: $Id$
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.7dev - 2009-03-13
 */
define('GALETTE_PHP_MIN', '7.1');
define('SMARTY_VERSION', '3.1.21');
define('ZEND_VERSION', '2.3.7');
define('ANALOG_VERSION', '1.0.7');
define('TCPDF_VERSION', '6.2.6');
define('JQUERY_VERSION', '1.10.2');
define('JQUERY_MIGRATE_VERSION', '1.2.1');
define('JQUERY_UI_VERSION', '1.10.3');
define('JQUERY_MARKITUP_VERSION', '1.1.14');
define('JQUERY_JQPLOT_VERSION', '1.0.8r1250');
define('PHP_MAILER_VERSION', '5.2.9');
define('PASSWORD_COMPAT_VERSION', '1.0.4');
define('SLIM_VERSION', '2.4.3');
define('SLIM__VIEWS_VERSION', '0.1.2');

==> galette-1.0.3.tar.bz2: galette-1.0.3/galette/config/versions.inc.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * External libraries versions
 * Defines various library versions, to avoid use of problematic symlinks under windows or via FTP.
 *
 * PHP version 5
 *
 * Copyright © 2009-2014 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Config
 * @package   Galette
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2009-2014 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.7dev - 2009-03-13
 */

define('GALETTE_PHP_MIN', '8.1');
define('GALETTE_MYSQL_MIN', '5.7');
define('GALETTE_MARIADB_MIN', '10.4');
define('GALETTE_PGSQL_MIN', '11')  ;
define('GALETTE_NIGHTLY', false);
define('GALETTE_VERSION', 'v1.0.3');
define('GALETTE_COMPAT_VERSION', '1.0.0');
define('GALETTE_DB_VERSION', '0.960');
